summaryrefslogtreecommitdiffstats
path: root/src/dirscanner.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dirscanner.h')
-rw-r--r--src/dirscanner.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/dirscanner.h b/src/dirscanner.h
index b25fc2d..a494052 100644
--- a/src/dirscanner.h
+++ b/src/dirscanner.h
@@ -28,13 +28,13 @@
#ifndef DIRSCANNER_H
#define DIRSCANNER_H
-#include <qobject.h>
-#include <qevent.h>
-#include <qthread.h>
-#include <qdir.h>
-#include <qstringlist.h>
-#include <qdict.h>
-#include <qlistview.h>
+#include <ntqobject.h>
+#include <ntqevent.h>
+#include <ntqthread.h>
+#include <ntqdir.h>
+#include <ntqstringlist.h>
+#include <ntqdict.h>
+#include <ntqlistview.h>
class DirScanner;
@@ -43,7 +43,7 @@ class DirScanner;
* dir scanning thread to the main application thread.
* @author Elad Lahav
*/
-class DirScanEvent : public QCustomEvent
+class DirScanEvent : public TQCustomEvent
{
public:
/** The event's unique ID. */
@@ -60,21 +60,21 @@ public:
/**
* A set of unique strings.
* Qt3 does not have a set class, so this is a simple implementation based on
* a QDict of dummy int pointers.
* @author Elad Lahav
*/
-class StringSet : public QDict<int>
+class StringSet : public TQDict<int>
{
public:
- StringSet() : QDict<int>() {}
+ StringSet() : TQDict<int>() {}
- void insert(const QString& sItem) {
+ void insert(const TQString& sItem) {
static int nDummy = 0;
- QDict<int>::insert(sItem, &nDummy);
+ TQDict<int>::insert(sItem, &nDummy);
}
- bool exists(const QString& sItem) {
+ bool exists(const TQString& sItem) {
return find(sItem) != NULL;
}
};
@@ -83,18 +83,18 @@ public:
* Scans a directory for files matching a given pattern, using a separate thread.
* @author Elad Lahav
*/
-class DirScanner : public QThread
+class DirScanner : public TQThread
{
public:
- DirScanner(QObject*, QDict<QListViewItem>*);
+ DirScanner(TQObject*, TQDict<TQListViewItem>*);
~DirScanner();
- void start(const QString&, const QString&, bool);
+ void start(const TQString&, const TQString&, bool);
/**
* @return The list of files scanned by this thread.
*/
- const QStringList& getFiles() { return m_slFiles; }
+ const TQStringList& getFiles() { return m_slFiles; }
/**
* Stops a scanning process, by setting the object's cancel flag.
@@ -111,10 +111,10 @@ protected:
private:
/** Pointer to an object that receives the scanner update events. */
- QObject* m_pEventReceiver;
+ TQObject* m_pEventReceiver;
/** Currently scanned directory. */
- QDir m_dir;
+ TQDir m_dir;
/**
* A set of already-scanned directories (prevents infinite loops in case
@@ -124,13 +124,13 @@ private:
/** Pointer to a list of files indexed by the file path (used to identify
files that should not appear in the scan results.) */
- QDict<QListViewItem>* m_pDicFiles;
+ TQDict<TQListViewItem>* m_pDicFiles;
/** Regular expression for scanning source files. */
- QString m_sNameFilter;
+ TQString m_sNameFilter;
/** The list of scanned file paths. */
- QStringList m_slFiles;
+ TQStringList m_slFiles;
/** A cancellation flag. Stops the scanning process when raised. */
bool m_bCancel;
@@ -138,7 +138,7 @@ private:
/** true to descend to child directories, false otherwise. */
bool m_bRecursive;
- int scanDir(QDir&);
+ int scanDir(TQDir&);
};
#endif
@@ -60,21 +60,21 @@ public:
/**
* A set of unique strings.
- * Qt3 does not have a set class, so this is a simple implementation based on
- * a QDict of dummy int pointers.
+ * TQt3 does not have a set class, so this is a simple implementation based on
+ * a TQDict of dummy int pointers.
* @author Elad Lahav
*/